Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EncodingHandler ¶
EncodingHandler handles http requests with "Accept-Encoding" header
Types ¶
type EncodingType ¶
type EncodingType string
EncodingType is type for Encodings
const ( // AES128GCM is the const for encoding aes128gcm AES128GCM EncodingType = "aes128gcm" // BR is the const for encoding br BR EncodingType = "br" // Compress is the const for encoding compress Compress EncodingType = "compress" // Deflate is the const for encoding deflate Deflate EncodingType = "deflate" // EXI is the const for encoding exi EXI EncodingType = "exi" // GZip is the const for encoding gzip GZip EncodingType = "gzip" // Identity is the const for encoding identity Identity EncodingType = "identity" // Pack200GZip is the const for encoding pack200-gzip Pack200GZip EncodingType = "pack200-gzip" // ZStd is the const for encoding zstd ZStd EncodingType = "zstd" // XCompress is the const for encoding x-compress XCompress EncodingType = "x-compress" // XGZip is the const for encoding x-gzip XGZip EncodingType = "x-gzip" // All is the const for encoding * All EncodingType = "*" )
Click to show internal directories.
Click to hide internal directories.